# History

## 0.5.0 (2020-01-10)

* **Breaking** Compatibility with nidhoggr_core 0.5.x

## 0.4.0 (2020-01-09)

* **Breaking** Compatibility with nidhoggr_core 0.4.x

## 0.3.0 (2020-01-06)

* **Breaking** Compatibility with nidhoggr_core 0.3.0

## 0.2.0 (2019-12-31)

* Used nidhoggr-core

## 0.1.0 (2019-12-31)

* First release on PyPI.
